OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Só son visibles para as persoas coincidentes mediante a integración do número de teléfono a través de Talk no móbil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Só visible para as persoas desta instancia e os convidados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Sincronizar só con servidores de confianza",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza e co caderno de enderezos global e público",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando…",
    "Unable to change password" : "Non é posíbel cambiar o contrasinal",
    "Very weak password" : "Contrasinal moi feble",
    "Weak password" : "Contrasinal feble",
    "So-so password" : "Contrasinal non moi aló",
    "Good password" : "Bo contrasinal",
    "Strong password" : "Contrasinal forte",
    "Groups" : "Grupos",
    "Group list is empty" : "A lista de grupos está baleira",
    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
    "{actor} added you to group {group}" : "{actor} engadiuno ao grupo {group}",
    "You added {user} to group {group}" : "Vostede engadiu a {actor} ao grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} engadiu a {user} ao grupo {group}",
    "An administrator added you to group {group}" : "Un administrador engadiuno ao grupo {group} ",
    "An administrator added {user} to group {group}" : "Un administrador engadiu a {user} ao grupo {group}",
    "{actor} removed you from group {group}" : "{actor} retirouno do grupo {group}",
    "You removed {user} from group {group}" : "Vostede retirou a {user} do grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} retirou a {user} do grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador retirouno do grupo {group} ",
    "An administrator removed {user} from group {group}" : "Un administrador retirou a {user} do grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Foron modificados os <strong>membros do seu grupo</strong>",
    "{actor} changed your password" : "{actor} cambiou o seu contrasinal",
    "You changed your password" : "Vostede cambiou o seu contrasinal",
    "Your password was reset by an administrator" : "O seu contrasinal foi restabelecido por un administrador",
    "Your password was reset" : "O seu contrasinal foi restabelecido",
    "{actor} changed your email address" : "{actor} cambiou o seu enderezo de correo",
    "You changed your email address" : "Vostede cambiou o seu enderezo de correo",
    "Your email address was changed by an administrator" : "O seu enderezo de correo foi cambiado por un administrador",
    "You created an app password for a session named \"{token}\"" : "Creou un contrasinal de aplicación para unha sesión chamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrador creou un contrasinal de aplicación para unha sesión chamada \"{token}\"",
    "You deleted app password \"{token}\"" : "Vostede eliminou o contrasinal da aplicación «{token}»",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Vostede renomeou o contrasinal da aplicación «{token}» como «{newToken}»",
    "You granted filesystem access to app password \"{token}\"" : "Vostede concedeu acceso ao sistema de ficheiros ao contrasinal da aplicación «{token}»",
    "You revoked filesystem access from app password \"{token}\"" : "Vostede revogou o acceso ao sistema de ficheiros dende o contrasinal da aplicación «{token}»",
    "Security" : "Seguridade",
    "You successfully logged in using two-factor authentication (%1$s)" : "Accedeu satisfactoriamente usando autenticación de dous factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Fallou un intento de acceso usando autenticación de dous factores (%1$s)",
    "Remote wipe was started on %1$s" : "Iniciouse a limpeza remota en %1$s",
    "Remote wipe has finished on %1$s" : "Rematou a limpeza remota en %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Foi modificado o seu <strong>contrasinal</strong> ou o seu <strong>correo electrónico</strong>",
    "Apps" : "Aplicacións",
    "Could not remove app." : "Non se puido eliminar a aplicación.",
    "Could not update app." : "Non se puido actualizar a aplicación.",
    "Wrong password" : "Contrasinal incorrecto",
    "Unable to change personal password" : "Non se puido cambiar o contrasinal persoal",
    "Saved" : "Gardado",
    "No user supplied" : "Non subministrado polo usuario",
    "Unable to change password. Password too long." : "Non se puido cambiar o contrasinal. O contrasinal é demasiado longo.",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Forneza un contrasinal de recuperación de administrador; senón perderase toda a información do usuario.",
    "Wrong admin recovery password. Please check the password and try again." : "Contrasinal de recuperación do administrador incorrecto. Comprobe o contrasinal e ténteo de novo.",
    "Backend does not support password change, but the user's encryption key was updated." : "O backend non admite o cambio de contrasinal, pero actualizouse a clave de cifrado do usuario.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalar e actualizar aplicacións a través da App Store ou Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está utilizando unha versión obsoleta %1$s (%2$s). Actualice o seu sistema operativo, caso contrario características como %3$s non funcionarán de xeito fiábel.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Non se puido determinar se a versión TLS de cURL está desactualizada ou non porque se produciu un erro durante a solicitude HTTPS contra https://nextcloud.com. Consulte o ficheiro de rexistro de Nextcloud para obter máis detalles.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "O módulo PHP OPcache non está cargado. Para un mellor rendemento, recoméndase cargalo na súa instalación de PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache está desactivado. Para un mellor rendemento, recoméndase aplicar <code>opcache.enable=1</code> á súa configuración de PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache está configurado para eliminar comentarios de código. Con OPcache activado, debe configurarse <code>opcache.save_comments=1</code> para que Nextcloud funcione.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud non pode usar a API OPcache. Con OPcache activado, é moi recomendable incluír todos os directorios de Nextcloud con <code>opcache.restrict_api</code> ou desactivar esta configuración para desactivar as restricións da API de OPcache, para evitar erros durante as actualizacións do núcleo de Nextcloud ou da aplicación.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud non pode usar a API OPcache. É moi recomendable incluír todos os directorios de Nextcloud con <code>opcache.restrict_api</code> ou desactivar esta configuración para desactivar as restricións da API de OPcache, para evitar erros durante as actualizacións do núcleo de Nextcloud ou das aplicacións.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "O OPcache baseado na memoria compartida está desactivado. Para un mellor rendemento, recoméndase aplicar <code>opcache.file_cache_only=0</code> á súa configuración de PHP e utilizar a caché de ficheiros só como caché de segundo nivel.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves OPcache está case superado. Para garantir que todos os scripts poden manterse na caché, recoméndase aplicar <code>opcache.max_accelerated_files</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer OPcache está case cheo. Para garantir que todos os scripts se poidan gardar na caché, recoméndase aplicar <code>opcache.memory_consumption</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer de cadeas internadas en OPcache está case cheo. Para asegurarse de que as cadeas que se repiten poidan almacenarse na caché de forma efectiva, recoméndase aplicar <code>opcache.interned_strings_buffer</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
    "Administrator documentation" : "Documentación do administrador",
    "User documentation" : "Documentación do usuario",
    "Invalid SMTP password." : "Contrasinal SMTP incorrecta.",
    "Email setting test" : "Proba do axuste do correo",
    "Well done, %s!" : "Ben feito, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se vostede ten recibido este correo, a configuración do correo semella ser correcta. ",
    "Email could not be sent. Check your mail server log" : "Non foi posíbel enviar o correo. Comprobe o rexistro do servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu un problema ao enviar o correo. Revise a súa configuración. (Erro: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Debes configurar o teu correo electrónico de usuario antes de poder enviar correos electrónicos de proba. Vaia a %spara iso.",
    "Users" : "Usuarios",
    "Invalid user" : "Usuario incorrecto",
    "Invalid mail address" : "Enderezo de correo incorrecto",
    "Settings saved" : "Axustes gardados",
    "Unable to change full name" : "Non é posíbel cambiar o nome completo",
    "Unable to change email address" : "Non é posíbel cambiar o enderezo de correo.",
    "Unable to set invalid phone number" : "Non é posíbel estabelecer un número de teléfono non válido",
    "Unable to set invalid website" : "Non se puido establecer o sitio web non válido",
    "Some account data was invalid" : "Algúns datos da conta non eran válidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar a súa conta de Twitter, publique o seguinte chío en Twitter (asegúrese de publicar sen ningún salto de liña):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar o seu sitio Web, engada o seguinte contido ao seu web-root en «.well-known/CloudIdVerificationCode.txt» (asegúrese de que o texto completo estea só nunha liña):",
    "%1$s changed your password on %2$s." : "%1$s cambiou o seu contrasinal en %2$s.",
    "Your password on %s was changed." : "Foi cambiado o seu contrasinal en %s.",
    "Your password on %s was reset by an administrator." : "O seu contrasinal en %s foi restabelecido por un administrador",
    "Your password on %s was reset." : "Foi restabelecido o seu contrasinal en %s.",
    "Password for %1$s changed on %2$s" : "Contrasinal para %1$s cambiado en %2$s",
    "Password changed for %s" : "Contrasinal cambiado por %s",
    "If you did not request this, please contact an administrator." : "Se vostede non solicitou isto, póñase en contacto co administrador.",
    "Your email address on %s was changed." : "Foi cambiado o seu enderezo de correo en %s.",
    "Your email address on %s was changed by an administrator." : "O seu enderezo de correo en %s foi cambiado por un administrador",
    "Email address for %1$s changed on %2$s" : "Enderezo de correo para %1$s cambiado en %2$s",
    "Email address changed for %s" : "Enderezo de correo cambiado por %s",
    "The new email address is %s" : "O novo enderezo de correo é %s",
    "Your %s account was created" : "Foi creada a conta %s",
    "Welcome aboard" : "Benvido a bordo",
    "Welcome aboard %s" : "Benvido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Benvido á súa conta , pode engadir, protexer e compartir os seus datos.",
    "Your username is: %s" : "O seu nome de usuario é: %s",
    "Set your password" : "Estabeleza o seu contrasinal",
    "Go to %s" : "Ira a %s",
    "Install Client" : "Instalar o cliente",
    "Logged in user must be a subadmin" : "O usuario rexistrado debe ser un subadministrador",
    "Settings" : "Axustes",
    "Personal" : "Persoal",
    "Administration" : "Administración",
    "Additional settings" : "Axustes adicionais",
    "Administration privileges" : "Privilexios de administración",
    "Groupware" : "Software colaborativo",
    "Overview" : "Vista xeral",
    "Basic settings" : "Axustes básicos",
    "Sharing" : "Compartindo",
    "Availability" : "Dispoñibilidade",
    "Calendar" : "Calendario",
    "Personal info" : "Información persoal",
    "Mobile & desktop" : "Móbil e escritorio",
    "Email server" : "Servidor de correo",
    "Security & setup warnings" : "Advertencias de seguridade e configuración",
    "Background jobs" : "Traballos en segundo plano",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Reshare" : "Volver compartir",
    "Unlimited" : "Sen límites",
    "Verifying" : "Verificando",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendente un traballo en segundo plano que comprobe os certificados SSL importados polo usuario. Volva comprobar máis adiante.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hai algúns certificados SSL importados polo usuario, que xa non se usan con Nextcloud 21. Pódense importar coa liña de ordes mediante a orde «occ security:certificates:import». As súas rutas dentro do directorio de datos amosanse deseguido.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Atopáronse UUID non válidos de usuarios ou grupos LDAP. Revisa a túa configuración de \"Anular detección de UUID\" na parte Experto da configuración LDAP e utiliza \"occ ldap:update-uuid\" para actualizalos.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "O antigo formato de cifrado de lado do servidor está activado. Recomendámoslle desactivalo.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Utilízase a versión \"%s\" de MariaDB. Nextcloud 21 ou superior non admite esta versión e require MariaDB 10.2 ou superior.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Utilízase a versión de MySQL \"%s\". Nextcloud 21 e superior non admite esta versión e requiren MySQL 8.0 ou MariaDB 10.2 ou superior.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Utilízase a versión de PostgreSQL \"%s\". Nextcloud 21 ou superior non admite esta versión e require PostgreSQL 9.6 ou superior.",
    "Profile information" : "Información do perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Imaxe de perfil, nome completo, correo electrónico, número de teléfono, enderezo, sitio web, Twitter, organización, función, título, biografía e se o teu perfil está activado",
    "Nextcloud settings" : "Axustes do Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí pode decidir que grupo pode acceder a determinadas seccións da configuración de administración.",
    "None" : "Ningún",
    "Unable to modify setting" : "Non se puido modificar a configuración",
    "Two-Factor Authentication" : "Autenticación de dous factores",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A autenticación de dous factores pode ser aplicada para todos os usuarios e grupos específicos. Se non tiveran configurado un provedor de dous factores, non podería acceder ao sistema.",
    "Enforce two-factor authentication" : "Obrigar a autenticación de dous factores",
    "Limit to groups" : "Límite para grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "A obrigatoriedade da autenticación de dous factores pode estabelecerse só para certos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "A autenticación de dous factores é obrigatoria para todos os membros os seguintes grupos.",
    "Enforced groups" : "Grupos obrigados",
    "Two-factor authentication is not enforced for members of the following groups." : "A autenticación de dous factores non é obrigatoria para os membros dos seguintes grupos.",
    "Excluded groups" : "Grupos excluídos",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando se seleccionan/exclúen os grupos, usase a seguinte lóxica para determinar se un usuario ten obrigada a A2F: Se non hai grupos seleccionados, a A2F está activa para todos agás os membros dos grupos excluídos. Se hai grupos seleccionados, a A2F está activa para todos os membros destes. Se un usuario está á vez nun grupo seleccionado e noutro excluído, o seleccionado ten preferencia e se lle obriga a A2F.",
    "Save changes" : "Gardar os cambios",
    "All" : "Todo",
    "Limit app usage to groups" : "Limitar o uso de aplicacións a grupos",
    "No results" : "Sen resultados",
    "Update to {version}" : "Actualizar a {version}",
    "Remove" : "Retirar",
    "Disable" : "Desactivar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión mínima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión máxima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Non é posíbel instalar esta aplicación por mor de non cumprirse as dependencias:",
    "View in store" : "Ver na tenda",
    "Visit website" : "Visite o sitio web",
    "Report a bug" : "Informar dun fallo",
    "Admin documentation" : "Documentación do administrador",
    "Developer documentation" : "Documentación do desenvolvedor",
    "This app is supported via your current Nextcloud subscription." : "Esta aplicación é compatíbel cos súa subscrición actual a Nextcloud.",
    "Supported" : "Compatíbel",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "As aplicacións destacadas están desenvolvidas por e dentro da comunidade. Ofrecen unha funcionalidade central e están preparadas para o seu uso en produción.",
    "Featured" : "Destacada",
    "Update to {update}" : "Actualizar a {update}",
    "All apps are up-to-date." : "Todas as aplicacións están actualizadas.",
    "Results from other categories" : "Resultados doutras categorías",
    "No apps found for your version" : "Non se atoparon aplicacións para a súa versión",
    "Disable all" : "Desactivar todo",
    "Enable all" : "Activar todo",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación ten unha actualización dispòñíbel.","%n aplicacións teñen unha actualización dispoñíbel."],
    "_Update_::_Update all_" : ["Actualizar","Actualiza todo"],
    "Marked for remote wipe" : "Marcado para limpeza remota",
    "Device settings" : "Axustes do dispositivo",
    "Allow filesystem access" : "Permitir o acceso aos  sistema de ficheiros",
    "Rename" : "Renomear",
    "Revoke" : "Revogar",
    "Wipe device" : "Limpar o dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "A revogación deste testemuño pode impedir a limpeza do seu dispositivo se aínda non iniciou a limpeza.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} aplicación de iOS",
    "{productName} Android app" : "{productName} aplicación de Android",
    "{productName} Talk for iOS" : "{productName} Talk para iOS",
    "{productName} Talk for Android" : "{productName} Talk para Android",
    "Sync client - {os}" : "Cliente de sincronización - {os}",
    "This session" : "Esta sesión",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividade",
    "Devices & sessions" : "Dispositivos e sesións",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, móbiles e de escritorio actualmente conectados á súa conta.",
    "Do you really want to wipe your data from this device?" : "Confirma que quere limpar os seus datos deste dispositivo?",
    "Confirm wipe" : "Confirmar a limpeza",
    "Error while creating device token" : "Produciuse un erro ao crear un testemuño de dispositivo",
    "Error while updating device token scope" : "Produciuse un erro ao actualizar o ámbito do testemuño do dispositivo",
    "Error while updating device token name" : "Produciuse un erro ao actualizar o nome do testemuño do dispositivo",
    "Error while deleting the token" : "Produciuse un erro ao eliminar o testemuño",
    "Error while wiping the device with the token" : "Produciuse un erro ao limpar o dispositivo co testemuño",
    "App name" : "Nome da aplicación",
    "Create new app password" : "Crear un novo contrasinal de aplicación",
    "Use the credentials below to configure your app or device." : "Use as seguintes credenciais para configurar a súa aplicación ou dispositivo. ",
    "For security reasons this password will only be shown once." : "Por razóns de seguridade ese contrasinal só se amosará unha vez. ",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Done" : "Feito",
    "Show QR code for mobile apps" : "Amosar un código QR para aplicacións móbiles",
    "Copied!" : "Copiado!",
    "Copy" : "Copiar",
    "Could not copy app password. Please copy it manually." : "Non foi posíbel copiar o contrasinal da app. Cópieo manualmente.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que o servidor funcione correctamente, é importante configurar correctamente os traballos en segundo plano. Cron é a configuración recomendada. Consulte a documentación para obter máis información.",
    "Last job execution ran {time}. Something seems wrong." : "A última execución do traballo executouse o {time}. Algo parece funcionar mal.",
    "Last job ran {relativeTime}." : "O último traballo executouse {relativeTime}.",
    "Background job did not run yet!" : "O traballo en segundo plano aínda non se executou!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Executar unha tarefa con cada páxina cargada. Caso de uso: instancia de usuario único.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php está rexistrado nun servizo webcron para chamar a cron.php cada 5 minutos a través de HTTP. Caso de uso: instancia moi pequena (de 1 a 5 usuarios segundo o uso).",
    "Cron (Recommended)" : "Cron (Recomendado)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para executar isto necesitase a extensión POSIX de PHP. Vexa a {linkstart}documentación de PHP{linkend} para obter máis detalles. ",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Use o servizo cron do sistema para chamar ao ficheiro cron.php cada 5 minutos. Recomendado para todos os casos.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "O cron.php debe ser executado polo usuario do sistema \"{user}\".",
    "Unable to update background job mode" : "Non se puido actualizar o modo de traballo en segundo plano",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new users." : "Activa ou desactiva o perfil por defecto para os novos usuarios.",
    "Enable" : "Activar",
    "Unable to update profile default setting" : "Non se puido actualizar a configuración predeterminada do perfil",
    "Server-side encryption" : "Cifrado na parte do servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "O cifrado do lado do servidor fai posíbel cifrar os ficheiros que van ser enviados a este servidor. Isto leva algunhas limitacións como penalizacións no rendemento, así que actíveo só se é necesario.",
    "Enable server-side encryption" : "Activar o cifrado na parte do servidor",
    "Please read carefully before activating server-side encryption:" : "Lea atentamente antes de activar o cifrado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que o cifrado estea activado, todos os ficheiros enviados ao servidor dende ese punto en diante cifraranse en repouso no servidor. Só será posíbel desactivar o cifrado nunha data posterior se o módulo de cifrado activado admite esa función, e se cumpran todas as condicións previas (por exemplo, o estabelecemento dunha clave de recuperación).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "O cifrado por si só non garante a seguridade do sistema. Vexa a documentación para obter máis información sobre como funciona a aplicación de cifrado e os casos de uso admitidos.",
    "Be aware that encryption always increases the file size." : "Teña presente que o cifrado sempre incrementa o tamaño do ficheiro.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Sempre é  bo crear copias de seguridade dos seus datos, no caso do cifrado, asegúrese de ter unha copia de seguridade das claves de cifrado xunto cos seus datos.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta é a advertencia final. Confirma que quere activar o cifrado?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Non hai cargado ningún módulo de cifrado, active un módulo de cifrado no menú de aplicacións.",
    "Select default encryption module:" : "Seleccionar o módulo predeterminado de cifrado:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Debes migrar as túas claves de cifrado do cifrado antigo (ownCloud <= 8.0) ao novo. Activa o \"Módulo de cifrado predeterminado\" e executa {command}",
    "Unable to update server side encryption config" : "Non se puido actualizar a configuración de cifrado do servidor",
    "Rename group" : "Cambiar o nome do grupo",
    "Remove group" : "Retirar o grupo",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Está a piques de retirar o grupo {group}. Os usuarios NON van seren eliminados.",
    "Please confirm the group removal " : "Confirme a retirada do grupo ",
    "Current password" : "Contrasinal actual",
    "New password" : "Novo contrasinal",
    "Change password" : "Cambiar o contrasinal",
    "Your profile information" : "A información do teu perfil",
    "Your profile picture" : "A túa imaxe de perfil",
    "Upload profile picture" : "Subir imaxe de perfil",
    "Choose profile picture from Files" : "Escolle a imaxe de perfil de Ficheiros",
    "Remove profile picture" : "Eliminar a imaxe de perfil",
    "Picture provided by original account" : "Imaxe fornecida pola conta orixinal ",
    "Cancel" : "Cancelar",
    "Set as profile picture" : "Establecer como imaxe de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ten en conta que pode tardar ata 24 horas en actualizar a túa foto de perfil en todas partes.",
    "Choose your profile picture" : "Escolle a túa imaxe de perfil",
    "Please select a valid png or jpg file" : "Seleccione un ficheiro png ou jpg válido",
    "Error setting profile picture" : "Produciuse un erro ao configurar a imaxe de perfil",
    "Error cropping profile picture" : "Produciuse un erro ao recortar a imaxe de perfil",
    "Error saving profile picture" : "Produciuse un erro ao gardar a imaxe de perfil",
    "Error removing profile picture" : "Produciuse un erro ao eliminar a imaxe de perfil",
    "Your biography" : "A túa biografía",
    "Details" : "Detalles",
    "You are a member of the following groups:" : "Vostede é membro dos seguintes grupos: ",
    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "O teu nome completo",
    "Email options" : "Opcións de correo electrónico",
    "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer o contrasinal e notificacións",
    "Remove primary email" : "Eliminar o correo electrónico principal",
    "Delete email" : "Eliminar o correo electrónico",
    "Unset as primary email" : "Desactivar como correo electrónico principal",
    "This address is not confirmed" : "Este enderezo non está confirmado",
    "Set as primary email" : "Establecer como correo electrónico principal",
    "Your email address" : "O seu enderezo de correo",
    "Additional email address {index}" : "Enderezo de correo electrónico adicional {index}",
    "Unable to delete primary email address" : "Non se puido eliminar o enderezo de correo electrónico principal",
    "Unable to update primary email address" : "Non se puido actualizar o enderezo de correo electrónico principal",
    "Unable to add additional email address" : "Non se puido engadir un enderezo de correo electrónico adicional",
    "Unable to update additional email address" : "Non se puido actualizar o enderezo de correo electrónico adicional",
    "Unable to delete additional email address" : "Non se puido eliminar o enderezo de correo electrónico adicional",
    "No email address set" : "Non hai un enderezo de correo definido",
    "Additional emails" : "Correos electrónicos adicionais",
    "Your handle" : "O teu apodo",
    "Your headline" : "O teu titular",
    "Language" : "Idioma",
    "Help translate" : "Axude na tradución",
    "Unable to update language" : "Non se puido actualizar o idioma",
    "No language set" : "Non foi estabelecido ningún idioma",
    "Locale" : "Configuración rexional",
    "Week starts on {firstDayOfWeek}" : "A semana comeza o {firstDayOfWeek}",
    "Unable to update locale" : "Non se puido actualizar a configuración rexional",
    "No locale set" : "Non se definiu ningunha configuración rexional",
    "Your location" : "A túa localización",
    "Your organisation" : "A súa organización",
    "Your phone number" : "O seu número de teléfono",
    "Edit your Profile visibility" : "Edita a visibilidade do teu Perfil",
    "Enable Profile" : "Activar o Perfil",
    "Unable to update profile enabled state" : "Non se puido actualizar o estado activado do perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "A configuración máis restritiva de visibilidade ou alcance é respectada no teu Perfil. Por exemplo, se a visibilidade está definida como \"Mostrar a todos\" e o ámbito está configurado como \"Privado\", respéctase \"Privado\".",
    "Unable to update visibility of {displayId}" : "Non se puido actualizar a visibilidade de {displayId}",
    "Your role" : "O teu cargo",
    "Your Twitter handle" : "O seu usuario do Twitter",
    "Your website" : "O seu sitio web",
    "No {property} set" : "Non hai {property} definida",
    "Unable to update {property}" : "Non se puido actualizar a {property}",
    "Change scope level of {property}, current scope is {scope}" : "Cambiar o nivel de ámbito de {property}, o ámbito actual é {scope}",
    "Unable to update federation scope of the primary {property}" : "Non se puido actualizar o ámbito de federación da {property} principal",
    "Unable to update federation scope of additional {property}" : "Non se puido actualizar o ámbito da federación de {property} adicional",
    "Add additional email" : "Engade correo electrónico adicional",
    "Add" : "Engadir",
    "You do not have permissions to see the details of this user" : "Vostede non ten permisos para ver os detalles deste usuario",
    "Add new password" : "Engadir un novo contrasinal",
    "Add new email address" : "Engadir un novo enderezo de correo",
    "Add user to group" : "Engadir usuario ao grupo",
    "Set user as admin for" : "Estabelecer o usuario como administrador para",
    "Select user quota" : "Seleccionar a cota de usuario",
    "Delete user" : "Eliminar usuario",
    "Wipe all devices" : "Limpar todos os dispositivos",
    "Disable user" : "Desactivar usuario",
    "Enable user" : "Activar usuario",
    "Resend welcome email" : "Volver enviar o correo de benvida",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "No caso de perder o dispositivo ou saír da organización, pode limpar os datos de Nextcloud de xeito remoto de todos os dispositivos asociados a {userid}. Só funciona se os dispositivos están conectados Á Internet.",
    "Remote wipe of devices" : "Limpeza remota de dispositivos",
    "Wipe {userid}'s devices" : "Limpar os dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar completamente a conta de {userid} incluíndo todos os seus ficheiros persoais, datos de aplicacións, etc.",
    "Account deletion" : "Eliminación de conta",
    "Delete {userid}'s account" : "Eliminar a conta de {userid}",
    "Welcome mail sent!" : "Enviado o correo de benvida!",
    "Edit User" : "Editar usuario",
    "Toggle user actions menu" : "Alternar o menú de accións do usuario",
    "{size} used" : "{size} usado",
    "New user" : "Novo usuario",
    "Will be autogenerated" : "Vai ser xerado automaticamente",
    "Display name" : "Nome a amosar",
    "Email" : "Correo",
    "Default language" : "Idioma predeterminado",
    "Add a new user" : "Engadir un novo usuario",
    "Group admin for" : "Administrador de grupo para",
    "Quota" : "Cota",
    "User backend" : "Infraestrutura do usuario",
    "Storage location" : "Localización do almacenamento",
    "Last login" : "Último acceso",
    "No users in here" : "Aquí non hai usuarios",
    "Default quota" : "Cota predeterminada",
    "Common languages" : "Idiomas habituais",
    "Other languages" : "Outras linguas",
    "Password change is disabled because the master key is disabled" : "O cambio de contrasinal está desactivado porque a clave principal está desactivada",
    "Passwordless authentication requires a secure connection." : "A autenticación sen contrasinal require dunha conexión segura.",
    "Add WebAuthn device" : "Engadir un dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorice o seu dispositivo WebAuthn.",
    "Name your device" : "Nome do seu dispositivo",
    "Adding your device …" : "Engadindo o seu dispositivo…",
    "Server error while trying to add WebAuthn device" : "Produciuse un erro do servidor cando se tentaba engadir un dispositivo WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Produciuse un erro do servidor cando se intentaba completar o rexistro do dispositivo WebAuthn",
    "Unnamed device" : "Dispositivo sen nome",
    "Passwordless Authentication" : "Autenticación sen contrasinal",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configurar a súa conta para a autenticación sen contrasinal seguindo o estándar FIDO2.",
    "No devices configured." : "Non hai dispositivos configurados.",
    "The following devices are configured for your account:" : "Os seguintes dispositivos están configurados para a súa conta:",
    "Your browser does not support WebAuthn." : "O seu navegador non é compatíbel co WebAuthn.",
    "Your apps" : "As súas aplicacións",
    "{license}-licensed" : "Licenciado baixo a {license}",
    "Changelog" : "Rexistro de cambios",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Enter group name" : "Introduza o nome do grupo",
    "Add group" : "Engadir un grupo",
    "Active users" : "Usuarios activos",
    "Admins" : "Administradores",
    "Disabled users" : "Usuarios desactivados",
    "Default quota:" : "Cota predeterminada:",
    "Select default quota" : "Seleccionar a cota predeterminada",
    "Show Languages" : "Amosar os idiomas",
    "Show last login" : "Amosar o último acceso",
    "Show user backend" : "Amosar a infraestrutura do usuario",
    "Show storage path" : "Amosar a ruta do almacenamento",
    "Send email to new user" : "Enviar correo ao novo usuario",
    "Not saved" : "Sen gardar",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo enviado",
    "Location" : "Localización",
    "Profile picture" : "Imaxe do perfil",
    "About" : "Sobre",
    "Full name" : "Nome completo",
    "Additional email" : "Correo electrónico adicional",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Phone number" : "Número de teléfono",
    "Role" : "Cargo",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverso (por exemplo, Mastodon)",
    "Website" : "Sitio web",
    "Profile visibility" : "Visibilidade do perfil",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Non dispoñible, xa que esta propiedade é necesaria para as funcións básicas, como compartir ficheiros e invitacións de calendario",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Non dispoñible porque a federación foi desactivada para a túa conta, ponte en contacto co administrador do sistema se tes algunha dúbida",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Non está dispoñible xa que non se permite publicar datos específicos do usuario no servidor de busca, póñase en contacto co administrador do sistema se tes algunha dúbida",
    "Active apps" : "Aplcativos activos",
    "Disabled apps" : "Aplicacións desactivadas",
    "Updates" : "Actualizacións",
    "App bundles" : "Paquetes de aplicacións",
    "Featured apps" : "Aplis destacadas",
    "Show to everyone" : "Mostrar a todos",
    "Show to logged in users only" : "Mostrar só a usuarios que iniciaron sesión",
    "Hide" : "Agochar",
    "Download and enable" : "Descargar e activar",
    "Enable untested app" : "Activar a aplicación sen probar",
    "The app will be downloaded from the App Store" : "A aplicación descargarase da Tenda de Aplicacións",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación non está marcado como compatíbel coa súa versión do Nextcloud. Se continúa, poderá instalar a aplicación. Teña en conta que é probábel que a aplicación non funcione como se agarda.",
    "Never" : "Nunca",
    "An error occurred during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non se pode continuar.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicación foi activada pero necesita ser actualizada. Vai ser redirixido cara a páxina de actualizarións en 5 segundos.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: esta aplicación non se pode activar porque fai que o servidor sexa inestable",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto co seu administrador se se trata dun erro.",
    "Documentation" : "Documentación",
    "Forum" : "Foro",
    "Login" : "Acceso",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Abrir a documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para que poida enviar correos, por exemplo para cambios de contrasinais e notificacións.",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "Sendmail mode" : "Modo do Sendmail",
    "From address" : "Dende o enderezo",
    "Server address" : "Enderezo do servidor",
    "Port" : "Porto",
    "Authentication method" : "Método de autenticación",
    "Only applies when authentication is required" : "Só se aplica cando é necesaria a autenticación",
    "Authentication required" : "É necesaria a autenticación",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome de usuario SMTP",
    "SMTP Password" : "Contrasinal SMTP",
    "Save" : "Gardar",
    "Test and verify email settings" : "Proba e verifica a configuración do correo electrónico",
    "Send email" : "Enviar o correo",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "É importante para a seguridade e o bo funcionamento da súa instancia que todo estea configurado correctamente. Para axudarlle niso, imos facer algunhas comprobacións automáticas. Vexa a documentación ligada para obter máis información. ",
    "All checks passed." : "Pasáronse todas as verificacións.",
    "There are some errors regarding your setup." : "Hai algún erro relativo aos seus axustes.",
    "There are some warnings regarding your setup." : "Hai algún aviso relativo aos seus axustes.",
    "Checking for system and security issues." : "Verificando incidencias de sistema e seguridade.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Volva verificar as <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, e comprobe que non haxa erros ou avisos no <a href=\"%2$s\">rexistro</a>. ",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Comprobe a seguridade do seu Nextcloud empregando o <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">noso escaneo de seguridade ↗</a>.",
    "Version" : "Versión",
    "You need to enable the File sharing App." : "Debes activar a Aplicación Compartir ficheiros.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode facer axustes finos do comportamento al compartir. Lea a documentación para obter máis más información.",
    "Allow apps to use the Share API" : "Permitir que as aplicacións empreguen a API para compartir",
    "Set default expiration date for shares" : "Estabeleza a data de caducidade predeterminada das comparticións",
    "Expire after" : "Caduca tras",
    "day(s)" : "día(s)",
    "Enforce expiration date" : "Forzar a data de caducidade",
    "Set default expiration date for shares to other servers" : "Establece a data de caducidade predeterminada para as accións compartidas con outros servidores",
    "Allow users to share via link and emails" : "Permitir aos usuarios compartir mediante ligazóns e correos electrónicos",
    "Allow public uploads" : "Permitir os envíos públicos",
    "Always ask for a password" : "Pedir sempre un contrasinal",
    "Enforce password protection" : "Forzar a protección por contrasinal",
    "Exclude groups from password requirements:" : "Excluír grupos dos requisitos de contrasinal:",
    "Set default expiration date" : "Definir a data predeterminada de caducidade",
    "Exclude groups from creating link shares:" : "Excluír grupos da creación de ligazóns compartidas:",
    "Allow resharing" : "Permitir compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Restrinxir os usuarios a compartir só cos usuarios dos seus grupos",
    "Exclude groups from sharing" : "Excluír grupos da compartición",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderán recibir comparticións, mais non inicialas.",
    "Allow username autocompletion in share dialog" : "Permitir autocompletar o nome de usuario no diálogo de compartir",
    "Allow username autocompletion to users within the same groups" : "Permitir autocompletar o nome de usuario aos usuarios dos mesmos grupos",
    "Allow username autocompletion to users based on phone number integration" : "Permitir o autocompletado do nome de usuario aos usuarios en función da integración do número de teléfono",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Se está activado o autocompletado \"mesmo grupo\" e a \"integración do número de teléfono\", unha coincidencia en calquera é suficiente para mostrar ao usuario.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir o autocompletado ao introducir o nome completo ou o enderezo de correo electrónico (ignorando a coincidencia que falta na axenda telefónica e estar no mesmo grupo)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Amosar o texto de exención de responsabilidade na páxina de envío de ligazóns publicas (amosarase só cando a lista de ficheiros estea agochada)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto amosarase na páxina de envío das ligazóns públicas cando a lista de ficheiros estea agochada.",
    "Default share permissions" : "Permisos predeterminados para compartir",
    "Reasons to use Nextcloud in your organization" : "Razóns para usar o Nextcloud na súa organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pola {communityopen}comunidade Nextcloud{linkclose}, o {githubopen}código fonte{linkclose} está licenciado baixo a  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Faga un Gústame na nosa páxina de Facebook",
    "Follow us on Twitter" : "Síganos no Twitter",
    "Follow us on Mastodon" : "Síganos na Mastodon",
    "Check out our blog" : "Visite o noso blog ",
    "Subscribe to our newsletter" : "Subscríbase ao noso boletín",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud non é compatible e as notificacións instantáneas non están dispoñibles.",
    "Use a second factor besides your password to increase security for your account." : "Empregue un segundo factor ademais do seu contrasinal para aumentar a seguridade da súa conta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "  Se usa aplicacións de terceiros para conectarse a Nextcloud, asegúrese de crear e configurar un contrasinal de aplicación para cada unha antes de activar a autenticación de segundo factor.",
    "An error occurred while changing your language. Please reload the page and try again." : "Produciuse un erro ao cambiar o seu idioma. Actualice a páxina e tenteo de novo.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Produciuse un erro ao cambiar a súa configuración rexional. Actualice a páxina e tenteo de novo.",
    "Select a profile picture" : "Seleccione unha imaxe para o perfil",
    "Week starts on {fdow}" : "A semana comeza o {fdow}",
    "You created app password \"{token}\"" : "Vostede creou o contrasinal da aplicación «{token}»",
    "An administrator created app password \"{token}\"" : "Un administrador creou o contrasinal da aplicación \"{token}\"",
    "Couldn't remove app." : "Non foi posíbel retirar a aplicación.",
    "Couldn't update app." : "Non foi posíbel actualizar a aplicación.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "A infraestrutura non admite o cambio de contrasinal, mais a clave de cifrado do usuario foi actualizada.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Non foi posíbel determinar se a versión TLS de cURL está desactualizada ou non porque se produciu un erro durante a solicitude HTTPS contra https://nextcloud.com. Consulte o ficheiro de rexistro de Nextcloud para obter máis detalles.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves OPcache está case superado. Para garantir que todos os scripts se poidan gardar na caché, recoméndase aplicar <code>opcache.max_accelerated_files</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
    "Admin privileges" : "Privilexios de administrador",
    "Unable to update biography" : "Non se puido actualizar a biografía",
    "Unable to update full name" : "Non se puido actualizar o nome completo",
    "No full name set" : "Non se definiu ningún nome completo",
    "Unable to update headline" : "Non se puido actualizar o titular",
    "Unable to update organisation" : "Non se puido actualizar a organización",
    "Unable to update role" : "Non se puido actualizar o cargo",
    "Change scope level of {accountProperty}" : "Cambiar o nivel de ámbito de {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Non se puido actualizar o ámbito de federación da {accountProperty} principal",
    "Unable to update federation scope of additional {accountProperty}" : "Non se puido actualizar o ámbito da federación de {accountProperty} adicional",
    "Migration in progress. Please wait until the migration is finished" : "A migración está en proceso. Agarde a que remate.",
    "Migration started …" : "Iniciada a migración ...",
    "Address" : "Enderezo",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non é posíbel continuar.",
    "Plain" : "Simple",
    "NT LAN Manager" : "Xestor NT LAN",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Lea detidamente antes de activar o cifrado do lado do servidor:",
    "Enable encryption" : "Activar o cifrado",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "É necesario migrar as súas claves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Active o «Módulo predeterminado de cifrado» e execute «occ encryption:migrate»",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "É necesario migrar as claves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo.",
    "Start migration" : "Iniciar a migración",
    "Last job execution ran %s. Something seems wrong." : "O último traballo executouse %s. Algo semella estar mal.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Hai %s que non se executa ningún traballo. Considere aumentar a frecuencia de execución.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Dende %s non se executou ningún traballo. Considere cambiar ao cron do sistema.",
    "Last job ran %s." : "O último traballo executouse %s.",
    "Background job didn’t run yet!" : "O traballo en segundo plano aínda non se executou!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Para que o servidor funcione correctamente, é importante configurar correctamente os traballos en segundo plano. \"Cron\" é a configuración recomendada. Consulte a documentación para obter máis información.",
    "Pick background job setting" : "Escolla os axustes do traballo en segundo plano",
    "Recommended" : "Recomendado",
    "The cron.php needs to be executed by the system user \"%s\"." : "O cron.php debe ser executado polo usuario do sistema «%s»",
    "Change privacy level of profile picture" : "Cambia o nivel de privacidade da imaxe de perfil",
    "Upload new" : "Novo envío",
    "Select from Files" : "Seleccionar dende Ficheiros",
    "Remove image" : "Retirar a imaxe",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Ten en conta que o avatar pode tardar ata 24 horas en actualizarse en todas partes.",
    "Choose as profile picture" : "Seleccionar como imaxe do perfil",
    "You are using <strong>%s</strong>" : "Está usando <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Está usando <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s%%)",
    "Change privacy level of phone number" : "Cambia o nivel de privacidade do número de teléfono",
    "Change privacy level of address" : "Cambia o nivel de privacidade do enderezo",
    "Your postal address" : "O seu enderezo postal",
    "Change privacy level of website" : "Cambiar o nivel de privacidade do sitio web",
    "It can take up to 24 hours before the account is displayed as verified." : "Pode levar ata 24 horas antes de que a conta apareza como como verificada.",
    "Link https://…" : "Ligazón https://…",
    "Change privacy level of Twitter profile" : "Cambia o nivel de privacidade do perfil de Twitter",
    "Twitter handle @…" : "Usuario do Twitter @…",
    "Choose profile picture from files" : "Escolle a imaxe de perfil dende Ficheiros"
},
"nplurals=2; plural=(n != 1);");
